#ifndef DBUSSERVICE_H
#define DBUSSERVICE_H
#include <QString>
#include <QObject>
#include <QtGui/qwindowdefs.h>

#include "libflyadmindbus_global.h"
//#include "flyadmindbusinterface.h"

class FlyAdminDbusInterface;

namespace FlyAdmin {

class LIBFLYADMINDBUS_EXPORT DbusService : public QObject
{
    Q_OBJECT
public:
    explicit DbusService(QObject *parent = nullptr);
    virtual ~DbusService();
public:
    void copy(const QString &sourceName, const QString &destName);
    bool move(const QString &sourceName, const QString &destName);
    void moveAndRestart(const QString &sourceName, const QString &destName, const QString &serviceName);
    void startService(const QString &serviceName);
    void stopService(const QString &serviceName);
    void restartService(const QString &serviceName);
    void enableService(const QString &serviceName);
    void disableService(const QString &serviceName);

    void NTPSync(const QString &serverName);
    int execSmthWithArgs(const QString &processName, const QStringList &args);
    qint64 execSmthDetachedWithArgs(const QString &processName, const QStringList &args);

    void setMainWindowId(WId id);
    void error(const QString &name, const QString &message);
signals:
    void showMessage(QString title, QString text);
    void syncError(QString text);
    void syncOK();
    void confWrited();
    void confWriteError();
    void processOutput(const QString &output);

private:
    void preAuthAction(const QString& action);
    QString getDBusError(int err);

    FlyAdminDbusInterface *ddemon;
    WId m_mainWindowId;

};

}
#endif // DBUSSERVICE_H
